
#ifndef ___gio_marshal_MARSHAL_H__
#define ___gio_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,STRING,STRING,FLAGS (./gio-marshal.list:1) */
G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_STRING_STRING_FLAGS (GClosure     *closure,
                                                                    GValue       *return_value,
                                                                    guint         n_param_values,
                                                                    const GValue *param_values,
                                                                    gpointer      invocation_hint,
                                                                    gpointer      marshal_data);

/* VOID:STRING,BOXED (./gio-marshal.list:2) */
G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* VOID:BOOLEAN,POINTER (./gio-marshal.list:3) */
G_GNUC_INTERNAL void _gio_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,ENUM (./gio-marshal.list:4) */
G_GNUC_INTERNAL void _gio_marshal_VOID__OBJECT_OBJECT_ENUM (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
                                                            const GValue *param_values,
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);

/* BOOLEAN:OBJECT,OBJECT (./gio-marshal.list:5) */
G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:STRING,BOXED,BOXED (./gio-marshal.list:6) */
G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_BOXED_BOXED (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
                                                            const GValue *param_values,
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);

/* BOOL:POINTER,INT (./gio-marshal.list:7) */
G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__POINTER_INT (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);
#define _gio_marshal_BOOL__POINTER_INT	_gio_marshal_BOOLEAN__POINTER_INT

/* BOOL:UINT (./gio-marshal.list:8) */
G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
#define _gio_marshal_BOOL__UINT	_gio_marshal_BOOLEAN__UINT

/* VOID:STRING,STRING,BOXED (./gio-marshal.list:9) */
G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_STRING_BOXED (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:BOOL,BOXED (./gio-marshal.list:10) */
G_GNUC_INTERNAL void _gio_marshal_VOID__BOOLEAN_BOXED (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
#define _gio_marshal_VOID__BOOL_BOXED	_gio_marshal_VOID__BOOLEAN_BOXED

/* VOID:BOXED,BOXED (./gio-marshal.list:11) */
G_GNUC_INTERNAL void _gio_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

G_END_DECLS

#endif /* ___gio_marshal_MARSHAL_H__ */

